# eric7.QScintilla.Lexers.LexerFortran77

Module implementing a Fortran lexer with some additional methods.

### Global Attributes

None

### Classes

LexerFortran77 | Subclass to implement some additional lexer dependant methods.

### Functions

createLexer | Function to instantiate a lexer object.

## LexerFortran77

Subclass to implement some additional lexer dependant methods.

### Derived from

Lexer, QsciLexerFortran77

### Class Attributes

None

### Class Methods

None

### Methods

LexerFortran77 | Constructor
autoCompletionWordSeparators | Public method to return the list of separators for autocompletion.
defaultKeywords | Public method to get the default keywords.
initProperties | Public slot to initialize the properties.
isCommentStyle | Public method to check, if a style is a comment style.
isStringStyle | Public method to check, if a style is a string style.

### Static Methods

None

#### LexerFortran77 (Constructor)

LexerFortran77(parent=None)

Constructor

parent
  parent widget of this lexer

#### LexerFortran77.autoCompletionWordSeparators

autoCompletionWordSeparators()

Public method to return the list of separators for autocompletion.

Return:
  list of separators (list of strings)

#### LexerFortran77.defaultKeywords

defaultKeywords(kwSet)

Public method to get the default keywords.

kwSet
  number of the keyword set (integer)

Return:
  string giving the keywords (string) or None

#### LexerFortran77.initProperties

initProperties()

Public slot to initialize the properties.

#### LexerFortran77.isCommentStyle

isCommentStyle(style)

Public method to check, if a style is a comment style.

style
  style to check (integer)

Return:
  flag indicating a comment style (boolean)

#### LexerFortran77.isStringStyle

isStringStyle(style)

Public method to check, if a style is a string style.

style
  style to check (integer)

Return:
  flag indicating a string style (boolean)

Up

## createLexer

createLexer(variant="", parent=None)

Function to instantiate a lexer object.

variant (str)
  name of the language variant
parent (QObject)
  parent widget of this lexer

Return:
  instantiated lexer object

Return Type:
  LexerFortran77

Up